@@ -5,11 +5,12 @@ from .iterators import n_th
 
 T = tp.TypeVar('T')
 U = tp.TypeVar('U')
+IteratorOrIterable = tp.Union[tp.Iterator[T], tp.Iterable[T]]
 
 
 # shamelessly copied from
 # https://medium.com/better-programming/is-this-the-last-element-of-my-python-for-loop-784f5ff90bb5
-def is_last(lst: tp.Iterable[T]) -> tp.Generator[tp.Tuple[bool, T], None, None]:
+def is_last(lst: IteratorOrIterable) -> tp.Iterator[tp.Tuple[bool, T]]:
     """
     Return every element of the list, alongside a flag telling is this the last element.
 
@@ -30,8 +31,8 @@ def is_last(lst: tp.Iterable[T]) -> tp.Generator[tp.Tuple[bool, T], None, None]:
     yield True, ret_var
 
 
-def add_next(lst: tp.Iterable[T], wrap_over: bool = False, skip_last: bool = False) -> tp.Iterator[
-    tp.Tuple[T, tp.Optional[T]]]:
+def add_next(lst: IteratorOrIterable, wrap_over: bool = False, skip_last: bool = False) -> tp.Iterator[
+        tp.Tuple[T, tp.Optional[T]]]:
     """
     Yields a 2-tuple of given iterable, presenting the next element as second element of the tuple.
 
@@ -64,7 +65,7 @@ def add_next(lst: tp.Iterable[T], wrap_over: bool = False, skip_last: bool = Fal
 
 
 def half_cartesian(seq1: tp.Iterable[T], include_same_pairs: bool = True) -> tp.Iterator[
-    tp.Tuple[T, T]]:
+        tp.Tuple[T, T]]:
     """
     Generate half of the Cartesian product of both sequences.
 
@@ -95,7 +96,7 @@ def half_cartesian(seq1: tp.Iterable[T], include_same_pairs: bool = True) -> tp.
                     yield elem1, elem2
 
 
-def group_quantity(length: int, seq: tp.Iterable[T]) -> tp.Generator[tp.List[T], None, None]:
+def group_quantity(length: int, seq: IteratorOrIterable) -> tp.Iterator[tp.List[T]]:
     """
     Slice an iterable into lists containing at most len entries.
 
@@ -104,18 +105,28 @@ def group_quantity(length: int, seq: tp.Iterable[T]) -> tp.Generator[tp.List[T],
     >>> assert list(group_quantity(3, [1, 2, 3, 4, 5, 6, 7, 8, 9, 10])) == [[1, 2, 3], [4, 5, 6],
     >>>                                                                     [7, 8, 9], [10]]
 
+    This correctly detects sequences, and uses an optimized variant via slicing if
+    a sequence is passed.
+
     :param length: p_len for the returning sequences
     :param seq: sequence to split
     """
-    entries = []
-    for elem in seq:
-        if len(entries) < length:
-            entries.append(elem)
-        else:
+    if isinstance(seq, tp.Sequence):
+        i = 0
+        while i < len(seq):
+            yield seq[i:i+length]
+            i += length
+    else:
+        entries = []
+        for elem in seq:
+            if len(entries) == length:
+                yield entries
+                entries = [elem]
+            else:
+                entries.append(elem)
+
+        if entries:
             yield entries
-            entries = [elem]
-    if entries:
-        yield entries
 
 
 class Multirun:
