@@ -2,7 +2,41 @@ import collections
 import random
 import typing as tp
 
-__all__ = ['stringify', 'split_shuffle_and_join', 'one_tuple']
+from satella.coding.decorators import for_argument
+
+from .merger import merge_series
+
+__all__ = ['stringify', 'split_shuffle_and_join', 'one_tuple',
+           'merge_series', 'pad_to_multiple_of_length']
+
+T = tp.TypeVar('T')
+
+
+@for_argument(list)
+def pad_to_multiple_of_length(seq: tp.Sequence[T], multiple_of: int,
+                              pad_with: tp.Optional[T] = None,
+                              pad_with_factory: tp.Optional[tp.Callable[[], T]] = None) -> \
+        tp.List[T]:
+    """
+    Make sequence multiple of length, ie. append elements to the sequence
+    until it's length is a multiple of multiple_of.
+
+    :param seq: sequence to lengthify
+    :param multiple_of: sequence returned will be a multiple of this length.
+    :param pad_with: argument with which to pad the sequence
+    :param pad_with_factory: a callable/0 that returns an element with which to pad the sequence
+    :return: a list with elements
+    """
+    if pad_with is not None and pad_with_factory is not None:
+        raise ValueError('You need to give either pad_with or pad_with_factory')
+
+    if pad_with_factory is None:
+        def pad_with_factory():
+            return pad_with
+
+    while len(seq) % multiple_of:
+        seq.append(pad_with_factory())
+    return seq
 
 
 def _stringify_none(str_none, stringifier):
